# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteMailGroupMemberReq(object):
    mailgroup_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # The unique ID or email address of a mail group, 示例值："xxxxxxxxxxxxxxx or test_mail_group@xxx.xx"
    member_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # The unique ID of a member in this mail group, 示例值："xxxxxxxxxxxxxxx"


@attr.s
class DeleteMailGroupMemberResp(object):
    pass


def _gen_delete_mail_group_member_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteMailGroupMemberResp,
        scope="Mail",
        api="DeleteMailGroupMember",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/mail/v1/mailgroups/:mailgroup_id/members/:member_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UnmergeSheetCellReq(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # spreadsheet 的 token，获取方式见[在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)
    range_: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 查询范围，包含 sheetId 与单元格范围两部分，目前支持四种索引方式，详见[在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)


@attr.s
class UnmergeSheetCellResp(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # spreadsheet 的 token


def _gen_unmerge_sheet_cell_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UnmergeSheetCellResp,
        scope="Drive",
        api="UnmergeSheetCell",
        method="POST",
        url="https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/:spreadsheetToken/unmerge_cells",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class ApplyVCReserveReqMeetingSettingsCallSettingCalleePstnSipInfo(object):
    nickname: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 给pstn/sip用户设置的临时昵称, 示例值："dodo"
    main_address: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # pstn/sip主机号, 示例值："1234"


@attr.s
class ApplyVCReserveReqMeetingSettingsCallSettingCallee(object):
    id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户ID, 示例值："ou_3ec3f6a28a0d08c45d895276e8e5e19b"
    user_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 用户类型, 示例值：1, 可选值有: `1`：lark用户, `2`：rooms用户, `3`：文档用户, `4`：neo单品用户, `5`：neo单品游客用户, `6`：pstn用户, `7`：sip用户
    pstn_sip_info: ApplyVCReserveReqMeetingSettingsCallSettingCalleePstnSipInfo = (
        attr.ib(default=None, metadata={"req_type": "json"})
    )  # pstn/sip信息


@attr.s
class ApplyVCReserveReqMeetingSettingsCallSetting(object):
    callee: ApplyVCReserveReqMeetingSettingsCallSettingCallee = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 被呼叫的用户


@attr.s
class ApplyVCReserveReqMeetingSettingsActionPermissionPermissionChecker(object):
    check_field: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 检查字段类型, 示例值：1, 可选值有: `1`：用户ID, `2`：用户类型, `3`：租户ID
    check_mode: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 检查方式, 示例值：1, 可选值有: `1`：在check_list中为有权限（白名单）, `2`：不在check_list中为有权限（黑名单）
    check_list: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 检查字段列表


@attr.s
class ApplyVCReserveReqMeetingSettingsActionPermission(object):
    permission: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 权限项, 示例值：1, 可选值有: `1`：是否能成为主持人, `2`：是否能邀请参会人, `3`：是否能加入会议
    permission_checkers: typing.List[
        ApplyVCReserveReqMeetingSettingsActionPermissionPermissionChecker
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 权限检查器列表，权限检查器之间为"逻辑或"的关系（即 有一个为true则拥有该权限）


@attr.s
class ApplyVCReserveReqMeetingSettings(object):
    topic: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 会议主题, 示例值："my meeting"
    action_permissions: typing.List[
        ApplyVCReserveReqMeetingSettingsActionPermission
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 会议权限配置列表，如果存在相同的权限配置项则它们之间为"逻辑或"的关系（即 有一个为true则拥有该权限）
    meeting_initial_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 会议初始类型, 示例值：1, 可选值有: `1`：多人会议, `2`：1v1呼叫
    call_setting: ApplyVCReserveReqMeetingSettingsCallSetting = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 1v1呼叫相关参数


@attr.s
class ApplyVCReserveReqUserIDType(object):
    pass


@attr.s
class ApplyVCReserveReq(object):
    user_id_type: ApplyVCReserveReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    end_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 预约到期时间（unix时间，单位sec），多人会议必填, 示例值："1608888867"
    meeting_settings: ApplyVCReserveReqMeetingSettings = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 会议设置


@attr.s
class ApplyVCReserveRespReserve(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 预约ID（预约的唯一标识）
    meeting_no: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 9位会议号（飞书用户可通过输入9位会议号快捷入会）
    url: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 会议链接（飞书用户可通过点击会议链接快捷入会）
    app_link: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # APPLink用于唤起飞书APP入会。"{?}"为占位符，用于配置入会参数，使用时需替换具体值：0表示关闭，1表示打开。preview为入会前的设置页，mic为麦克风，speaker为扬声器，camera为摄像头
    end_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 预约到期时间（unix时间，单位sec）


@attr.s
class ApplyVCReserveResp(object):
    reserve: ApplyVCReserveRespReserve = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 预约数据


def _gen_apply_vc_reserve_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=ApplyVCReserveResp,
        scope="VC",
        api="ApplyVCReserve",
        method="POST",
        url="https://open.feishu.cn/open-apis/vc/v1/reserves/apply",
        body=request,
        method_option=_new_method_option(options),
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeletePublicMailboxMemberReq(object):
    public_mailbox_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 公共邮箱唯一标识或公共邮箱地址, 示例值："xxxxxxxxxxxxxxx 或 test_public_mailbox@xxx.xx"
    member_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 公共邮箱内成员唯一标识, 示例值："xxxxxxxxxxxxxxx"


@attr.s
class DeletePublicMailboxMemberResp(object):
    pass


def _gen_delete_public_mailbox_member_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeletePublicMailboxMemberResp,
        scope="Mail",
        api="DeletePublicMailboxMember",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/mail/v1/public_mailboxes/:public_mailbox_id/members/:member_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class AnswerHelpdeskTicketUserQueryReqFAQScore(object):
    pass


@attr.s
class AnswerHelpdeskTicketUserQueryReqFAQ(object):
    id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # faq服务台内唯一标识, 示例值："12345"
    score: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # faq匹配得分, 示例值：0.9


@attr.s
class AnswerHelpdeskTicketUserQueryReq(object):
    ticket_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 工单ID, 示例值："6945345902185807891"
    event_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 事件ID,可从订阅事件中提取, 示例值："abcd"
    faqs: typing.List[AnswerHelpdeskTicketUserQueryReqFAQ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # faq结果列表


@attr.s
class AnswerHelpdeskTicketUserQueryResp(object):
    pass


def _gen_answer_helpdesk_ticket_user_query_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=AnswerHelpdeskTicketUserQueryResp,
        scope="Helpdesk",
        api="AnswerHelpdeskTicketUserQuery",
        method="POST",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/tickets/:ticket_id/answer_user_query",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateDrivePublicPermissionV1OldReq(object):
    token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文件的 token，获取方式见 [对接前说明](https://open.feishu.cn/document/ukTMukTMukTM/uczNzUjL3czM14yN3MTN)的第 4 项
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文档类型  "doc"  or  "sheet"
    copy_print_export_status: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 可创建副本/打印/导出/复制设置（不传则保持原值）：<br>true - 所有可访问此文档的用户<br>false - 有编辑权限的用户
    comment: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 可评论设置（不传则保持原值）：<br>true - 所有可访问此文档的用户<br>false - 有编辑权限的用户
    tenant_shareable: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 租户内用户是否有共享权限（不传则保持原值）
    link_share_entity: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 链接共享（不传则保持原值）：<br>"tenant_readable" - 组织内获得链接的人可阅读<br>"tenant_editable" - 组织内获得链接的人可编辑<br>"anyone_readable" - 获得链接的任何人可阅读<br>"anyone_editable" - 获得链接的任何人可编辑
    external_access: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否允许分享到租户外开关（不传则保持原值）
    invite_external: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 非owner是否允许邀请外部人（不传则保持原值）


@attr.s
class UpdateDrivePublicPermissionV1OldResp(object):
    is_success: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否成功


def _gen_update_drive_public_permission_v1_old_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateDrivePublicPermissionV1OldResp,
        scope="Drive",
        api="UpdateDrivePublicPermissionV1Old",
        method="POST",
        url="https://open.feishu.cn/open-apis/drive/permission/public/update",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

import logging

import requests
from typing import Tuple

from pylark.api_service_auth import LarkAuthService
from pylark.api_service_contact import LarkContactService
from pylark.api_service_message import LarkMessageService
from pylark.api_service_chat import LarkChatService
from pylark.api_service_bot import LarkBotService
from pylark.api_service_calendar import LarkCalendarService
from pylark.api_service_drive import LarkDriveService
from pylark.api_service_bitable import LarkBitableService
from pylark.api_service_meeting_room import LarkMeetingRoomService
from pylark.api_service_vc import LarkVCService
from pylark.api_service_application import LarkApplicationService
from pylark.api_service_mail import LarkMailService
from pylark.api_service_approval import LarkApprovalService
from pylark.api_service_helpdesk import LarkHelpdeskService
from pylark.api_service_admin import LarkAdminService
from pylark.api_service_human_auth import LarkHumanAuthService
from pylark.api_service_ai import LarkAIService
from pylark.api_service_attendance import LarkAttendanceService
from pylark.api_service_file import LarkFileService
from pylark.api_service_okr import LarkOKRService
from pylark.api_service_ehr import LarkEHRService
from pylark.api_service_tenant import LarkTenantService
from pylark.api_service_search import LarkSearchService
from pylark.api_service_hire import LarkHireService
from pylark.api_service_task import LarkTaskService
from pylark.api_service_acs import LarkACSService

from pylark.log import logger
from pylark.lark_request import RawRequestReq, Response, RawRequestDataClass, Request


class Lark(object):
    app_id: str
    app_secret: str
    custom_url: str
    custom_secret: str

    auth: LarkAuthService
    ai: LarkAIService

    def __init__(
        self,
        app_id="",
        app_secret="",
        custom_url="",
        custom_secret="",
    ):
        # service

        self.auth = LarkAuthService(cli=self)
        self.contact = LarkContactService(cli=self)
        self.message = LarkMessageService(cli=self)
        self.chat = LarkChatService(cli=self)
        self.bot = LarkBotService(cli=self)
        self.calendar = LarkCalendarService(cli=self)
        self.drive = LarkDriveService(cli=self)
        self.bitable = LarkBitableService(cli=self)
        self.meeting_room = LarkMeetingRoomService(cli=self)
        self.vc = LarkVCService(cli=self)
        self.application = LarkApplicationService(cli=self)
        self.mail = LarkMailService(cli=self)
        self.approval = LarkApprovalService(cli=self)
        self.helpdesk = LarkHelpdeskService(cli=self)
        self.admin = LarkAdminService(cli=self)
        self.human_auth = LarkHumanAuthService(cli=self)
        self.ai = LarkAIService(cli=self)
        self.attendance = LarkAttendanceService(cli=self)
        self.file = LarkFileService(cli=self)
        self.okr = LarkOKRService(cli=self)
        self.ehr = LarkEHRService(cli=self)
        self.tenant = LarkTenantService(cli=self)
        self.search = LarkSearchService(cli=self)
        self.hire = LarkHireService(cli=self)
        self.task = LarkTaskService(cli=self)
        self.acs = LarkACSService(cli=self)

        self.app_id = app_id
        self.app_secret = app_secret
        self.custom_secret = custom_secret
        self.custom_url = custom_url

    def with_tenant(self, tenant_key: str):
        pass

    def raw_request(self, req: RawRequestReq) -> Tuple[RawRequestDataClass, Response]:
        logger.info("[lark] %s#%s call api", req.scope, req.api)

        req.headers = self.prepare_headers(req)

        return Request.raw_request(cli=self, req=req)

    def prepare_headers(self, req: RawRequestReq) -> dict:
        headers = {}
        if req.method != "GET":
            headers["Content-Type"] = "application/json; charset=utf-8"

        if req.need_user_access_token and req.method_option.user_access_token != "":
            headers["Authorization"] = "Bearer " + req.method_option.user_access_token
        elif req.need_tenant_access_token:
            res, _ = self.auth.get_tenant_access_token()
            headers["Authorization"] = "Bearer " + res.token

        if req.need_helpdesk_access_token:
            headers[
                "X-Lark-Helpdesk-Authorization"
            ] = ""  # base64.StdEncoding.EncodeToString([]byte(r.helpdeskID + ":" + r.helpdeskToken))

        return headers

    def do_request(self, request_parm: RawRequestReq, real_response) -> Response:
        response = Response()
        real_req = self.parse_request_param(request_parm)

        response.method = real_req["method"]
        response.url = real_req["url"]
        response.header = real_req["header"]

        logger.debug("[lark] request %s#%s, %s %s, header=%s, body=%s", "")

        return response

    def parse_request_param(self, req: RawRequestReq):
        return {"method": "", "url": "", "header": {}}



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetCalendarFreeBusyListReqUserIDType(object):
    pass


@attr.s
class GetCalendarFreeBusyListReq(object):
    user_id_type: GetCalendarFreeBusyListReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    time_min: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 查询时段开始时间，需要url编码, 示例值："2020-10-28T12:00:00+08:00"
    time_max: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 查询时段结束时间，需要url编码, 示例值："2020-12-28T12:00:00+08:00"
    user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户user_id，输入时与 room_id 二选一, 示例值："ou_xxxxxxxxxx"
    room_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 会议室room_id，输入时与 user_id 二选一, 示例值："omm_xxxxxxxxxx"


@attr.s
class GetCalendarFreeBusyListRespFreebusy(object):
    start_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 忙闲信息开始时间，RFC3339 date_time 格式
    end_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 忙闲信息结束时间，RFC3339 date_time 格式


@attr.s
class GetCalendarFreeBusyListResp(object):
    freebusy_list: typing.List[GetCalendarFreeBusyListRespFreebusy] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 日历上请求时间区间内的忙闲信息


def _gen_get_calendar_free_busy_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetCalendarFreeBusyListResp,
        scope="Calendar",
        api="GetCalendarFreeBusyList",
        method="POST",
        url="https://open.feishu.cn/open-apis/calendar/v4/freebusy/list",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateSheetPropertyReqProperties(object):
    title: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # spreadsheet 的标题，最大长度100个字符


@attr.s
class UpdateSheetPropertyReq(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # spreadsheet 的 token，获取方式见[在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)
    properties: UpdateSheetPropertyReqProperties = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # spreadsheet 的属性


@attr.s
class UpdateSheetPropertyResp(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # spreadsheet 的 token
    title: str = attr.ib(default="", metadata={"req_type": "json"})  # spreadsheet 的标题


def _gen_update_sheet_property_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateSheetPropertyResp,
        scope="Drive",
        api="UpdateSheetProperty",
        method="PUT",
        url="https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/:spreadsheetToken/properties",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetEmployeeTypeEnumListReq(object):
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果, 示例值："3"
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 分页大小, 示例值：10, 最大值：`100`


@attr.s
class GetEmployeeTypeEnumListRespItemI18nContent(object):
    locale: str = attr.ib(default="", metadata={"req_type": "json"})  # 语言
    value: str = attr.ib(default="", metadata={"req_type": "json"})  # i18n内容


@attr.s
class GetEmployeeTypeEnumListRespItem(object):
    enum_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 枚举值id
    enum_value: str = attr.ib(default="", metadata={"req_type": "json"})  # 枚举值
    content: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 枚举内容, 长度范围：`1` ～ `100` 字符
    enum_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 类型, 可选值有: `1`：内置类型, `2`：自定义
    enum_status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 类型, 可选值有: `1`：激活, `2`：未激活
    i18n_content: GetEmployeeTypeEnumListRespItemI18nContent = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # i18n定义


@attr.s
class GetEmployeeTypeEnumListResp(object):
    items: typing.List[GetEmployeeTypeEnumListRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 枚举数据
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否还有更多项
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token


def _gen_get_employee_type_enum_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetEmployeeTypeEnumListResp,
        scope="Contact",
        api="GetEmployeeTypeEnumList",
        method="GET",
        url="https://open.feishu.cn/open-apis/contact/v3/employee_type_enums",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_admin_admin_dept_stats_get import (
    GetAdminDeptStatsReq,
    GetAdminDeptStatsResp,
    _gen_get_admin_dept_stats_req,
)
from pylark.api_service_admin_admin_user_stats_get import (
    GetAdminUserStatsReq,
    GetAdminUserStatsResp,
    _gen_get_admin_user_stats_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkAdminService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def get_admin_dept_stats(
        self, request: GetAdminDeptStatsReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetAdminDeptStatsResp, Response]:
        return self.cli.raw_request(_gen_get_admin_dept_stats_req(request, options))

    def get_admin_user_stats(
        self, request: GetAdminUserStatsReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetAdminUserStatsResp, Response]:
        return self.cli.raw_request(_gen_get_admin_user_stats_req(request, options))



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateApprovalCarbonCopyReq(object):
    approval_code: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批定义 code
    instance_code: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批实例 code
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 发起抄送的人的 user_id
    open_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 发起抄送的人的 open_id，如果传了 user_id 则优先使用 user_id，二者不能同时为空
    cc_user_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 被抄送人的 user_id 列表
    cc_open_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 被抄送人的 open_id 列表，与 cc_user_ids 不可同时为空
    comment: str = attr.ib(default="", metadata={"req_type": "json"})  # 抄送留言


@attr.s
class CreateApprovalCarbonCopyResp(object):
    pass


def _gen_create_approval_carbon_copy_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateApprovalCarbonCopyResp,
        scope="Approval",
        api="CreateApprovalCarbonCopy",
        method="POST",
        url="https://www.feishu.cn/approval/openapi/v2/instance/cc",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetBitableMetaReq(object):
    app_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # bitable app token, 示例值："appbcbWCzen6D8dezhoCH2RpMAh"


@attr.s
class GetBitableMetaRespApp(object):
    app_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 多维表格的 app_token
    revision: int = attr.ib(default=0, metadata={"req_type": "json"})  # 多维表格的版本号


@attr.s
class GetBitableMetaResp(object):
    app: GetBitableMetaRespApp = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 多维表格元数据


def _gen_get_bitable_meta_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetBitableMetaResp,
        scope="Bitable",
        api="GetBitableMeta",
        method="GET",
        url="https://open.feishu.cn/open-apis/bitable/v1/apps/:app_token",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetApplicationOrderReq(object):
    order_id: str = attr.ib(default="", metadata={"req_type": "query"})  # 订单ID


@attr.s
class GetApplicationOrderRespOrder(object):
    order_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 订单ID，唯一标识
    price_plan_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 价格方案ID，唯一标识
    price_plan_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 价格方案类型 "trial" -试用；"permanent"-一次性付费；"per_year"-企业年付费；"per_month"-企业月付费；"per_seat_per_year"-按人按年付费；"per_seat_per_month"-按人按月付费；"permanent_count"-按次付费；
    seats: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 实际购买人数 仅对price_plan_type为per_seat_per_year和per_seat_per_month 有效
    buy_count: int = attr.ib(default=0, metadata={"req_type": "json"})  # 购买数量 总是为1
    create_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 订单创建时间戳
    pay_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 订单支付时间戳
    status: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 订单当前状态，"normal" -正常；"refund"-已退款；
    buy_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 购买类型，"buy" - 普通购买;"upgrade"-为升级购买(仅price_plan_type 为per_year，per_month，per_seat_per_year，per_seat_per_month时可升级购买);"renew" - 续费购买；
    src_order_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 源订单ID，当前订单为升级购买时，即buy_type为upgrade时，此字段记录源订单等ID
    dst_order_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 升级后的新订单ID，当前订单如果做过升级购买，此字段记录升级购买后生成的新订单ID，当前订单仍然有效
    order_pay_price: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 订单实际支付金额, 单位分
    tenant_key: str = attr.ib(default="", metadata={"req_type": "json"})  # 租户唯一标识


@attr.s
class GetApplicationOrderResp(object):
    order: GetApplicationOrderRespOrder = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 订单信息


def _gen_get_application_order_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetApplicationOrderResp,
        scope="Application",
        api="GetApplicationOrder",
        method="GET",
        url="https://open.feishu.cn/open-apis/pay/v1/order/get",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_chat_create import (
    CreateChatReq,
    CreateChatResp,
    _gen_create_chat_req,
)
from pylark.api_service_chat_get import GetChatReq, GetChatResp, _gen_get_chat_req
from pylark.api_service_chat_update import (
    UpdateChatReq,
    UpdateChatResp,
    _gen_update_chat_req,
)
from pylark.api_service_chat_delete import (
    DeleteChatReq,
    DeleteChatResp,
    _gen_delete_chat_req,
)
from pylark.api_service_chat_get_list_of_self import (
    GetChatListOfSelfReq,
    GetChatListOfSelfResp,
    _gen_get_chat_list_of_self_req,
)
from pylark.api_service_chat_search import (
    SearchChatReq,
    SearchChatResp,
    _gen_search_chat_req,
)
from pylark.api_service_chat_member_get_list import (
    GetChatMemberListReq,
    GetChatMemberListResp,
    _gen_get_chat_member_list_req,
)
from pylark.api_service_chat_member_in import (
    IsInChatReq,
    IsInChatResp,
    _gen_is_in_chat_req,
)
from pylark.api_service_chat_member_add import (
    AddChatMemberReq,
    AddChatMemberResp,
    _gen_add_chat_member_req,
)
from pylark.api_service_chat_member_delete import (
    DeleteChatMemberReq,
    DeleteChatMemberResp,
    _gen_delete_chat_member_req,
)
from pylark.api_service_chat_join import JoinChatReq, JoinChatResp, _gen_join_chat_req
from pylark.api_service_chat_announcement_get import (
    GetChatAnnouncementReq,
    GetChatAnnouncementResp,
    _gen_get_chat_announcement_req,
)
from pylark.api_service_chat_announcement_update import (
    UpdateChatAnnouncementReq,
    UpdateChatAnnouncementResp,
    _gen_update_chat_announcement_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkChatService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def create_chat(
        self, request: CreateChatReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateChatResp, Response]:
        return self.cli.raw_request(_gen_create_chat_req(request, options))

    def get_chat(
        self, request: GetChatReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetChatResp, Response]:
        return self.cli.raw_request(_gen_get_chat_req(request, options))

    def update_chat(
        self, request: UpdateChatReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateChatResp, Response]:
        return self.cli.raw_request(_gen_update_chat_req(request, options))

    def delete_chat(
        self, request: DeleteChatReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteChatResp, Response]:
        return self.cli.raw_request(_gen_delete_chat_req(request, options))

    def get_chat_list_of_self(
        self, request: GetChatListOfSelfReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetChatListOfSelfResp, Response]:
        return self.cli.raw_request(_gen_get_chat_list_of_self_req(request, options))

    def search_chat(
        self, request: SearchChatReq, options: typing.List[str] = None
    ) -> typing.Tuple[SearchChatResp, Response]:
        return self.cli.raw_request(_gen_search_chat_req(request, options))

    def get_chat_member_list(
        self, request: GetChatMemberListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetChatMemberListResp, Response]:
        return self.cli.raw_request(_gen_get_chat_member_list_req(request, options))

    def is_in_chat(
        self, request: IsInChatReq, options: typing.List[str] = None
    ) -> typing.Tuple[IsInChatResp, Response]:
        return self.cli.raw_request(_gen_is_in_chat_req(request, options))

    def add_chat_member(
        self, request: AddChatMemberReq, options: typing.List[str] = None
    ) -> typing.Tuple[AddChatMemberResp, Response]:
        return self.cli.raw_request(_gen_add_chat_member_req(request, options))

    def delete_chat_member(
        self, request: DeleteChatMemberReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteChatMemberResp, Response]:
        return self.cli.raw_request(_gen_delete_chat_member_req(request, options))

    def join_chat(
        self, request: JoinChatReq, options: typing.List[str] = None
    ) -> typing.Tuple[JoinChatResp, Response]:
        return self.cli.raw_request(_gen_join_chat_req(request, options))

    def get_chat_announcement(
        self, request: GetChatAnnouncementReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetChatAnnouncementResp, Response]:
        return self.cli.raw_request(_gen_get_chat_announcement_req(request, options))

    def update_chat_announcement(
        self, request: UpdateChatAnnouncementReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateChatAnnouncementResp, Response]:
        return self.cli.raw_request(_gen_update_chat_announcement_req(request, options))



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class BatchUpdateSheetReqRequestDeleteSheet(object):
    sheet_id: str = attr.ib(default="", metadata={"req_type": "json"})  # sheetId


@attr.s
class BatchUpdateSheetReqRequestCopySheetDestination(object):
    title: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 目标工作表名称。不填为 old_title(副本_0)


@attr.s
class BatchUpdateSheetReqRequestCopySheetSource(object):
    sheet_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 源 sheetId


@attr.s
class BatchUpdateSheetReqRequestCopySheet(object):
    source: BatchUpdateSheetReqRequestCopySheetSource = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 需要复制的工作表资源
    destination: BatchUpdateSheetReqRequestCopySheetDestination = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 工作表 的属性


@attr.s
class BatchUpdateSheetReqRequestAddSheetProperties(object):
    title: str = attr.ib(default="", metadata={"req_type": "json"})  # 工作表标题
    index: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 新增工作表的位置，不填默认往前增加工作表


@attr.s
class BatchUpdateSheetReqRequestAddSheet(object):
    properties: BatchUpdateSheetReqRequestAddSheetProperties = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 工作表属性


@attr.s
class BatchUpdateSheetReqRequest(object):
    add_sheet: BatchUpdateSheetReqRequestAddSheet = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 增加工作表
    copy_sheet: BatchUpdateSheetReqRequestCopySheet = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 复制工作表
    delete_sheet: BatchUpdateSheetReqRequestDeleteSheet = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 删除 sheet


@attr.s
class BatchUpdateSheetReq(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # spreadsheet 的 token，获取方式见[在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)
    requests: typing.List[BatchUpdateSheetReqRequest] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 请求操作，支持增、删、复制工作表 ，三个操作选一个


@attr.s
class BatchUpdateSheetRespReplyDeleteSheet(object):
    result: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 删除工作表是否成功
    sheet_id: str = attr.ib(default="", metadata={"req_type": "json"})  # sheetId


@attr.s
class BatchUpdateSheetRespReplyCopySheet(object):
    sheet_id: str = attr.ib(default="", metadata={"req_type": "json"})  # sheetId
    title: str = attr.ib(default="", metadata={"req_type": "json"})  # 工作表标题
    index: int = attr.ib(default=0, metadata={"req_type": "json"})  # 工作表位置


@attr.s
class BatchUpdateSheetRespReplyAddSheet(object):
    sheet_id: str = attr.ib(default="", metadata={"req_type": "json"})  # sheetId
    title: str = attr.ib(default="", metadata={"req_type": "json"})  # 工作表标题
    index: int = attr.ib(default=0, metadata={"req_type": "json"})  # 工作表位置


@attr.s
class BatchUpdateSheetRespReply(object):
    add_sheet: BatchUpdateSheetRespReplyAddSheet = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 增加/复制工作表的属性
    copy_sheet: BatchUpdateSheetRespReplyCopySheet = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 增加/复制工作表的属性
    delete_sheet: BatchUpdateSheetRespReplyDeleteSheet = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 删除工作表


@attr.s
class BatchUpdateSheetResp(object):
    replies: typing.List[BatchUpdateSheetRespReply] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 返回本次相关操作工作表的结果


def _gen_batch_update_sheet_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=BatchUpdateSheetResp,
        scope="Drive",
        api="BatchUpdateSheet",
        method="POST",
        url="https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/:spreadsheetToken/sheets_batch_update",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetCalendarACLListReqUserIDType(object):
    pass


@attr.s
class GetCalendarACLListReq(object):
    user_id_type: GetCalendarACLListReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果, 示例值："xxx"
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 分页大小, 示例值：10，小于10取10, 最大值：`50`
    calendar_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 日历ID, 示例值："feishu.cn_xxxxxxxxxx@group.calendar.feishu.cn"


@attr.s
class GetCalendarACLListRespACLScope(object):
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 权限类型，当type为User时，值为open_id/user_id/union_id, 可选值有: `user`：用户
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID


@attr.s
class GetCalendarACLListRespACLRole(object):
    pass


@attr.s
class GetCalendarACLListRespACL(object):
    acl_id: str = attr.ib(default="", metadata={"req_type": "json"})  # acl资源ID
    role: GetCalendarACLListRespACLRole = attr.ib(
        factory=lambda: GetCalendarACLListRespACLRole(), metadata={"req_type": "json"}
    )  # 对日历的访问权限, 可选值有: `unknown`：未知权限, `free_busy_reader`：游客，只能看到忙碌/空闲信息, `reader`：订阅者，查看所有日程详情, `writer`：编辑者，创建及修改日程, `owner`：管理员，管理日历及共享设置
    scope: GetCalendarACLListRespACLScope = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 权限范围


@attr.s
class GetCalendarACLListResp(object):
    acls: typing.List[GetCalendarACLListRespACL] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 入参日历对应的acl列表
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否还有更多项
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token


def _gen_get_calendar_acl_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetCalendarACLListResp,
        scope="Calendar",
        api="GetCalendarACLList",
        method="GET",
        url="https://open.feishu.cn/open-apis/calendar/v4/calendars/:calendar_id/acls",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class PartUploadDriveMediaReqFile(object):
    pass


@attr.s
class PartUploadDriveMediaReq(object):
    upload_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分片上传事务ID, 示例值："123456"
    seq: int = attr.ib(default=0, metadata={"req_type": "json"})  # 块号，从0开始计数, 示例值：0
    size: int = attr.ib(default=0, metadata={"req_type": "json"})  # 块大小, 示例值：4194304
    checksum: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文件分块adler32校验和(可选), 示例值："12345678"
    file: typing.Union[str, bytes, io.BytesIO] = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 文件分片内容, 示例值：file binary


@attr.s
class PartUploadDriveMediaResp(object):
    pass


def _gen_part_upload_drive_media_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=PartUploadDriveMediaResp,
        scope="Drive",
        api="PartUploadDriveMedia",
        method="POST",
        url="https://open.feishu.cn/open-apis/drive/v1/medias/upload_part",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
        is_file=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DownloadDriveFileReqRange(object):
    pass


@attr.s
class DownloadDriveFileReq(object):
    file_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 文件标识符, 示例值："boxcnabCdefg12345"
    range_: DownloadDriveFileReqRange = attr.ib(
        factory=lambda: DownloadDriveFileReqRange(),
        metadata={"req_type": "header", "header": "range"},
    )  # 指定文件下载部分, 示例值："bytes=0-1024"


@attr.s
class DownloadDriveFileRespFile(object):
    pass


@attr.s
class DownloadDriveFileResp(object):
    file: typing.Union[str, bytes, io.BytesIO] = attr.ib(
        default=None, metadata={"resp_type": "header"}
    )
    filename: str = attr.ib(default="", metadata={"resp_type": "header"})  # 文件名


@attr.s
class DownloadDriveFileResp(object):
    is_file: bool = attr.ib(factory=lambda: bool(), metadata={"resp_type": "header"})
    code: int = attr.ib(default=0, metadata={"resp_type": "header"})
    msg: str = attr.ib(default="", metadata={"resp_type": "header"})
    data: DownloadDriveFileResp = attr.ib(
        default=None, metadata={"resp_type": "header"}
    )


def _gen_download_drive_file_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DownloadDriveFileResp,
        scope="Drive",
        api="DownloadDriveFile",
        method="GET",
        url="https://open.feishu.cn/open-apis/drive/v1/files/:file_token/download",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetAttendanceUserStatisticsSettingsReqEmployeeType(object):
    pass


@attr.s
class GetAttendanceUserStatisticsSettingsReq(object):
    employee_type: GetAttendanceUserStatisticsSettingsReqEmployeeType = attr.ib(
        factory=lambda: GetAttendanceUserStatisticsSettingsReqEmployeeType(),
        metadata={"req_type": "query"},
    )  # 用户 ID 类型, 可选值有: `employee_id`, `employee_no`
    locale: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 语言类型, 可选值有: `en`：英文, `ja`：日文, `zh`：中文
    stats_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 统计类型,      , 可选值有: `daily`：日度统计, `month`：月度统计


@attr.s
class GetAttendanceUserStatisticsSettingsRespViewItemChildItem(object):
    code: str = attr.ib(default="", metadata={"req_type": "json"})  # 标题编号
    value: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 是否开启,      , 可选值有: `0`：关闭, `1`：开启
    title: str = attr.ib(default="", metadata={"req_type": "json"})  # 标题名称
    column_type: int = attr.ib(default=0, metadata={"req_type": "json"})  # 标题类型
    read_only: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否只读
    min_value: str = attr.ib(default="", metadata={"req_type": "json"})  # 最小值
    max_value: str = attr.ib(default="", metadata={"req_type": "json"})  # 最大值


@attr.s
class GetAttendanceUserStatisticsSettingsRespViewItem(object):
    code: str = attr.ib(default="", metadata={"req_type": "json"})  # 标题编号
    title: str = attr.ib(default="", metadata={"req_type": "json"})  # 标题名称
    child_items: typing.List[
        GetAttendanceUserStatisticsSettingsRespViewItemChildItem
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 子标题


@attr.s
class GetAttendanceUserStatisticsSettingsRespView(object):
    view_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 视图 ID
    stats_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 统计类型, 可选值有: `daily`：日度统计, `month`：月度统计
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户 ID
    items: typing.List[GetAttendanceUserStatisticsSettingsRespViewItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 一级标题


@attr.s
class GetAttendanceUserStatisticsSettingsResp(object):
    view: GetAttendanceUserStatisticsSettingsRespView = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 统计视图


def _gen_get_attendance_user_statistics_settings_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetAttendanceUserStatisticsSettingsResp,
        scope="Attendance",
        api="GetAttendanceUserStatisticsSettings",
        method="POST",
        url="https://open.feishu.cn/open-apis/attendance/v1/user_stats_views/query",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class BatchGetUserByIDReq(object):
    emails: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "query"}
    )  # 要查询的用户邮箱，最多 50 条。
    mobiles: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "query"}
    )  # 要查询的用户手机号，最多 50 条。<br>非中国大陆地区的手机号需要添加以 “+” 开头的国家 / 地区代码，并且需要进行 URL 转义。<br>


@attr.s
class BatchGetUserByIDRespEmailUser(object):
    open_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户的 open_id。
    user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户的 user_id。<br>只有已申请 `获取用户UserID` 权限的企业自建应用返回此字段。


@attr.s
class BatchGetUserByIDRespEmailUser(object):
    open_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户的 open_id。
    user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户的 user_id。<br>只有已申请 `获取用户UserID` 权限的企业自建应用返回此字段。


@attr.s
class BatchGetUserByIDResp(object):
    email_users: BatchGetUserByIDRespEmailUser = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 根据邮箱查询到的用户，key 为邮箱，value 为查询到用户的 array。<br>目前同一个邮箱最多只能查询到一个用户。
    emails_not_exist: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 没有匹配记录的邮箱。
    mobile_users: BatchGetUserByIDRespEmailUser = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 根据手机号查询到的用户，key 为手机号，value 为查询到用户的 array。<br>目前同一个手机号最多只能查询到一个用户。
    mobiles_not_exist: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 没有匹配记录的手机号。


def _gen_batch_get_user_by_id_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=BatchGetUserByIDResp,
        scope="Contact",
        api="BatchGetUserByID",
        method="GET",
        url="https://open.feishu.cn/open-apis/user/v1/batch_get_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetVCDailyReportReq(object):
    start_time: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 开始时间（unix时间，单位sec）, 示例值："1608888867"
    end_time: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 结束时间（unix时间，单位sec）, 示例值："1608888966"


@attr.s
class GetVCDailyReportRespMeetingReportDailyReport(object):
    date: str = attr.ib(default="", metadata={"req_type": "json"})  # 日期（unix时间，单位sec）
    meeting_count: str = attr.ib(default="", metadata={"req_type": "json"})  # 会议数量
    meeting_duration: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 会议时长（单位sec）
    participant_count: str = attr.ib(default="", metadata={"req_type": "json"})  # 参会人数


@attr.s
class GetVCDailyReportRespMeetingReport(object):
    total_meeting_count: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 总会议数量
    total_meeting_duration: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 总会议时长（单位sec）
    total_participant_count: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 总参会人数
    daily_report: GetVCDailyReportRespMeetingReportDailyReport = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 每日会议报告列表


@attr.s
class GetVCDailyReportResp(object):
    meeting_report: GetVCDailyReportRespMeetingReport = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 会议报告


def _gen_get_vc_daily_report_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetVCDailyReportResp,
        scope="VC",
        api="GetVCDailyReport",
        method="GET",
        url="https://open.feishu.cn/open-apis/vc/v1/reports/get_daily",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetAttendanceUserApprovalReqEmployeeType(object):
    pass


@attr.s
class GetAttendanceUserApprovalReq(object):
    employee_type: GetAttendanceUserApprovalReqEmployeeType = attr.ib(
        factory=lambda: GetAttendanceUserApprovalReqEmployeeType(),
        metadata={"req_type": "query"},
    )  # 请求体中的 user_ids 的员工工号类型，必选字段，可用值：【employee_id（员工的 employeeId），employee_no（员工工号）】，示例值："employee_id"
    user_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # employee_no 或 employee_id 列表
    check_date_from: int = attr.ib(default=0, metadata={"req_type": "json"})  # 查询的起始工作日
    check_date_to: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 查询的结束工作日，与 check_date_from 的时间间隔不超过30天


@attr.s
class GetAttendanceUserApprovalRespUserApprovalTrip(object):
    start_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 开始时间，时间格式为 yyyy-MM-dd HH:mm:ss
    end_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 结束时间，时间格式为 yyyy-MM-dd HH:mm:ss
    reason: str = attr.ib(default="", metadata={"req_type": "json"})  # 出差理由
    approve_pass_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 审批通过时间，时间格式为 yyyy-MM-dd HH:mm:ss
    approve_apply_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 审批申请时间，时间格式为 yyyy-MM-dd HH:mm:ss


@attr.s
class GetAttendanceUserApprovalRespUserApprovalOvertimeWorkDuration(object):
    pass


@attr.s
class GetAttendanceUserApprovalRespUserApprovalOvertimeWork(object):
    duration: float = attr.ib(default=None, metadata={"req_type": "json"})  # 加班时长
    unit: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 加班时长单位，可用值：【1（天），2（小时）】
    category: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 加班日期类型，可用值：【1（工作日），2（休息日），3（节假日）】
    type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 加班规则类型，可用值：【0（不关联加班规则），1（调休），2（加班费）】
    start_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 开始时间，时间格式为 yyyy-MM-dd HH:mm:ss
    end_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 结束时间，时间格式为 yyyy-MM-dd HH:mm:ss


@attr.s
class GetAttendanceUserApprovalRespUserApprovalLeaveI18nNames(object):
    ch: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文描述
    en: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文描述
    ja: str = attr.ib(default="", metadata={"req_type": "json"})  # 日文描述


@attr.s
class GetAttendanceUserApprovalRespUserApprovalLeave(object):
    uniq_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 假期类型唯一 ID，代表一种假期类型，长度小于 14
    unit: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 假期时长单位，可用值：【1（天），0（小时），4（分钟）】
    start_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 开始时间，时间格式为 yyyy-MM-dd HH:mm:ss
    end_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 结束时间，时间格式为 yyyy-MM-dd HH:mm:ss
    i18n_names: GetAttendanceUserApprovalRespUserApprovalLeaveI18nNames = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 假期多语言展示，格式为 map，key 为["ch"、"en"、"ja"]，其中 ch 代表中文，en 代表英文、ja 代表日文
    default_locale: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 默认语言类型，由于飞书客户端支持中、英、日三种语言，当用户切换语言时，如果假期名称没有所对应语言的名称，则会使用默认语言的名称，可用值：【ch（中文），en（英文），ja（日文）】
    reason: str = attr.ib(default="", metadata={"req_type": "json"})  # 请假理由
    approve_pass_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 审批通过时间，时间格式为 yyyy-MM-dd HH:mm:ss
    approve_apply_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 审批申请时间，时间格式为 yyyy-MM-dd HH:mm:ss


@attr.s
class GetAttendanceUserApprovalRespUserApprovalOutI18nNames(object):
    ch: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文描述
    en: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文描述
    ja: str = attr.ib(default="", metadata={"req_type": "json"})  # 日文描述


@attr.s
class GetAttendanceUserApprovalRespUserApprovalOut(object):
    uniq_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 外出类型唯一 ID，代表一种外出类型，长度小于 14
    unit: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 外出时长单位，可用值：【1（天），2（小时），3（半天），4（半小时）】
    interval: int = attr.ib(default=0, metadata={"req_type": "json"})  # 外出时长（单位秒）
    start_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 开始时间，时间格式为 yyyy-MM-dd HH:mm:ss
    end_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 结束时间，时间格式为 yyyy-MM-dd HH:mm:ss
    i18n_names: GetAttendanceUserApprovalRespUserApprovalOutI18nNames = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 外出多语言展示，格式为 map，key 为["ch"、"en"、"ja"]，其中 ch 代表中文，en 代表英文、ja 代表日文
    default_locale: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 默认语言类型，由于飞书客户端支持中、英、日三种语言，当用户切换语言时，如果外出名称没有所对应语言的名称，则会使用默认语言的名称
    reason: str = attr.ib(default="", metadata={"req_type": "json"})  # 外出理由
    approve_pass_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 审批通过时间
    approve_apply_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 审批申请时间


@attr.s
class GetAttendanceUserApprovalRespUserApproval(object):
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批用户 ID
    date: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批作用时间
    outs: typing.List[GetAttendanceUserApprovalRespUserApprovalOut] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 外出信息
    leaves: typing.List[GetAttendanceUserApprovalRespUserApprovalLeave] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 请假信息
    overtime_works: typing.List[
        GetAttendanceUserApprovalRespUserApprovalOvertimeWork
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 加班信息
    trips: typing.List[GetAttendanceUserApprovalRespUserApprovalTrip] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 出差信息


@attr.s
class GetAttendanceUserApprovalResp(object):
    user_approvals: typing.List[GetAttendanceUserApprovalRespUserApproval] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 审批结果列表


def _gen_get_attendance_user_approval_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetAttendanceUserApprovalResp,
        scope="Attendance",
        api="GetAttendanceUserApproval",
        method="POST",
        url="https://open.feishu.cn/open-apis/attendance/v1/user_approvals/query",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetApplicationAppListReq(object):
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页起始位置标示，不填表示从头开始
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 单页需求最大个数（最大 100），0 自动最大个数
    lang: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 优先展示的应用信息的语言版本（zh_cn：中文，en_us：英文，ja_jp：日文）
    status: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 要返回的应用的状态，0:停用；1:启用；-1:全部，默认为 -1


@attr.s
class GetApplicationAppListRespAppList(object):
    app_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 应用 ID
    primary_language: str = attr.ib(default="", metadata={"req_type": "json"})  # 应用首选语言
    app_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 应用名称
    description: str = attr.ib(default="", metadata={"req_type": "json"})  # 应用描述
    avatar_url: str = attr.ib(default="", metadata={"req_type": "json"})  # 应用 icon
    app_scene_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 应用类型，0：企业自建应用；1：应用商店应用
    status: int = attr.ib(default=0, metadata={"req_type": "json"})  # 启停状态，0：停用；1：启用


@attr.s
class GetApplicationAppListResp(object):
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 下一个请求页应当给的起始位置
    page_size: int = attr.ib(default=0, metadata={"req_type": "json"})  # 本次请求实际返回的页大小
    total_count: int = attr.ib(default=0, metadata={"req_type": "json"})  # 可用的应用总数
    has_more: int = attr.ib(default=0, metadata={"req_type": "json"})  # 是否还有更多应用
    lang: str = attr.ib(default="", metadata={"req_type": "json"})  # 当前选择的版本语言
    app_list: GetApplicationAppListRespAppList = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 应用列表


def _gen_get_application_app_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetApplicationAppListResp,
        scope="Application",
        api="GetApplicationAppList",
        method="GET",
        url="https://open.feishu.cn/open-apis/application/v3/app/list",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetVCTopUserReportReq(object):
    start_time: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 开始时间（unix时间，单位sec）, 示例值："1608888867"
    end_time: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 结束时间（unix时间，单位sec）, 示例值："1608889966"
    limit: int = attr.ib(default=0, metadata={"req_type": "query"})  # 取前多少位, 示例值：10
    order_by: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 排序依据（降序）, 示例值：1, 可选值有: `1`：会议数量, `2`：会议时长


@attr.s
class GetVCTopUserReportRespTopUserReport(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户名
    user_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 用户类型, 可选值有: `1`：lark用户, `2`：rooms用户, `3`：文档用户, `4`：neo单品用户, `5`：neo单品游客用户, `6`：pstn用户, `7`：sip用户
    meeting_count: str = attr.ib(default="", metadata={"req_type": "json"})  # 会议数量
    meeting_duration: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 会议时长（单位sec）


@attr.s
class GetVCTopUserReportResp(object):
    top_user_report: GetVCTopUserReportRespTopUserReport = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # top用户列表


def _gen_get_vc_top_user_report_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetVCTopUserReportResp,
        scope="VC",
        api="GetVCTopUserReport",
        method="GET",
        url="https://open.feishu.cn/open-apis/vc/v1/reports/get_top_user",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetEHREmployeeListReqUserIDType(object):
    pass


@attr.s
class GetEHREmployeeListReq(object):
    view: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 返回数据类型, 示例值："basic", 可选值有: `basic`：概览，只返回 id、name 等基本信息, `full`：明细，返回系统标准字段和自定义字段集合
    status: typing.List[int] = attr.ib(
        factory=lambda: [], metadata={"req_type": "query"}
    )  # 员工状态，不传代表查询所有员工状态,实际在职 = 2&4, 示例值：1
    type: typing.List[int] = attr.ib(
        factory=lambda: [], metadata={"req_type": "query"}
    )  # 雇员类型，不传代表查询所有雇员类型, 示例值：1
    start_time: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 查询开始时间（创建时间 &gt;= 此时间）, 示例值：1608690517811
    end_time: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 查询结束时间（创建时间 &lt;= 此时间）, 示例值：1608690517811
    user_id_type: GetEHREmployeeListReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`,, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    user_ids: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # user_id、open_id 或 union_id，默认为 open_id。,如果传入的值不是 open_id，需要一并传入 user_id_type 参数。, 示例值："ou_8ebd4f35d7101ffdeb4771d7c8ec517e"
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果, 示例值："1cGaS5rM1F9u9g/xjVMipKrmQHo5CHYa+uE3D3OnAmc="
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 分页大小, 示例值：10, 最大值：`100`


@attr.s
class GetEHREmployeeListRespItemCustomField(object):
    key: str = attr.ib(default="", metadata={"req_type": "json"})  # 自定义字段key
    label: str = attr.ib(default="", metadata={"req_type": "json"})  # 自定义字段名称
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 自定义字段类型, 可选值有: `text`：文本类型, `date`：日期类型，如 2020-01-01, `option`：枚举类型, `file`：附件类型
    value: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 根据 type 不同，结构不同，不同 type 对应的数据结构在 type 的枚举值中有描述


@attr.s
class GetEHREmployeeListRespItemSystemFieldsOffboardingFile(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 下载文件所需要的 Token
    mime_type: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件类型
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 名称
    size: int = attr.ib(default=0, metadata={"req_type": "json"})  # 大小


@attr.s
class GetEHREmployeeListRespItemSystemFieldsCertOfMerit(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 下载文件所需要的 Token
    mime_type: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件类型
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 名称
    size: int = attr.ib(default=0, metadata={"req_type": "json"})  # 大小


@attr.s
class GetEHREmployeeListRespItemSystemFieldsGraduationCert(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 下载文件所需要的 Token
    mime_type: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件类型
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 名称
    size: int = attr.ib(default=0, metadata={"req_type": "json"})  # 大小


@attr.s
class GetEHREmployeeListRespItemSystemFieldsDiplomaPhoto(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 下载文件所需要的 Token
    mime_type: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件类型
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 名称
    size: int = attr.ib(default=0, metadata={"req_type": "json"})  # 大小


@attr.s
class GetEHREmployeeListRespItemSystemFieldsIDPhoto(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 下载文件所需要的 Token
    mime_type: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件类型
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 名称
    size: int = attr.ib(default=0, metadata={"req_type": "json"})  # 大小


@attr.s
class GetEHREmployeeListRespItemSystemFieldsIDPhotoEmSide(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 下载文件所需要的 Token
    mime_type: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件类型
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 名称
    size: int = attr.ib(default=0, metadata={"req_type": "json"})  # 大小


@attr.s
class GetEHREmployeeListRespItemSystemFieldsIDPhotoPoSide(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 下载文件所需要的 Token
    mime_type: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件类型
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 名称
    size: int = attr.ib(default=0, metadata={"req_type": "json"})  # 大小


@attr.s
class GetEHREmployeeListRespItemSystemFieldsWorkExp(object):
    company: str = attr.ib(default="", metadata={"req_type": "json"})  # 公司
    department: str = attr.ib(default="", metadata={"req_type": "json"})  # 部门
    job: str = attr.ib(default="", metadata={"req_type": "json"})  # 职位
    start: str = attr.ib(default="", metadata={"req_type": "json"})  # 开始日期
    end: str = attr.ib(default="", metadata={"req_type": "json"})  # 截止日期
    description: str = attr.ib(default="", metadata={"req_type": "json"})  # 工作描述


@attr.s
class GetEHREmployeeListRespItemSystemFieldsFormerWorkExp(object):
    company: str = attr.ib(default="", metadata={"req_type": "json"})  # 公司
    department: str = attr.ib(default="", metadata={"req_type": "json"})  # 部门
    job: str = attr.ib(default="", metadata={"req_type": "json"})  # 职位
    start: str = attr.ib(default="", metadata={"req_type": "json"})  # 开始日期
    end: str = attr.ib(default="", metadata={"req_type": "json"})  # 截止日期
    description: str = attr.ib(default="", metadata={"req_type": "json"})  # 工作描述


@attr.s
class GetEHREmployeeListRespItemSystemFieldsEducation(object):
    level: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 学历, 可选值有: `1`：小学, `2`：初中, `3`：高中, `4`：职业高级中学, `5`：中等专业学校, `6`：大专, `7`：本科, `8`：硕士, `9`：博士
    school: str = attr.ib(default="", metadata={"req_type": "json"})  # 毕业学校
    major: str = attr.ib(default="", metadata={"req_type": "json"})  # 专业
    degree: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 学位, 可选值有: `1`：学士, `2`：硕士, `3`：博士
    start: str = attr.ib(default="", metadata={"req_type": "json"})  # 开始日期
    end: str = attr.ib(default="", metadata={"req_type": "json"})  # 结束日期


@attr.s
class GetEHREmployeeListRespItemSystemFieldsHighestLevelOfEdu(object):
    level: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 学历, 可选值有: `1`：小学, `2`：初中, `3`：高中, `4`：职业高级中学, `5`：中等专业学校, `6`：大专, `7`：本科, `8`：硕士, `9`：博士
    school: str = attr.ib(default="", metadata={"req_type": "json"})  # 毕业学校
    major: str = attr.ib(default="", metadata={"req_type": "json"})  # 专业
    degree: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 学位, 可选值有: `1`：学士, `2`：硕士, `3`：博士
    start: str = attr.ib(default="", metadata={"req_type": "json"})  # 开始日期
    end: str = attr.ib(default="", metadata={"req_type": "json"})  # 结束日期


@attr.s
class GetEHREmployeeListRespItemSystemFieldsEmergencyContact(object):
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 紧急联系人姓名
    relationship: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 与紧急联系人的关系, 可选值有: `1`：父母, `2`：配偶, `3`：子女, `4`：兄弟姐妹, `5`：朋友, `6`：其他
    mobile: str = attr.ib(default="", metadata={"req_type": "json"})  # 手机号


@attr.s
class GetEHREmployeeListRespItemSystemFieldsPrimaryEmergencyContact(object):
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 紧急联系人姓名
    relationship: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 与紧急联系人的关系, 可选值有: `1`：父母, `2`：配偶, `3`：子女, `4`：兄弟姐妹, `5`：朋友, `6`：其他
    mobile: str = attr.ib(default="", metadata={"req_type": "json"})  # 手机号


@attr.s
class GetEHREmployeeListRespItemSystemFieldsContractCompany(object):
    id: int = attr.ib(default=0, metadata={"req_type": "json"})  # 公司 ID
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 公司名称


@attr.s
class GetEHREmployeeListRespItemSystemFieldsProbationMonths(object):
    pass


@attr.s
class GetEHREmployeeListRespItemSystemFieldsIDType(object):
    pass


@attr.s
class GetEHREmployeeListRespItemSystemFieldsNativeRegion(object):
    iso_code: str = attr.ib(default="", metadata={"req_type": "json"})  # ISO 编码
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 名称


@attr.s
class GetEHREmployeeListRespItemSystemFieldsWorkLocation(object):
    id: int = attr.ib(default=0, metadata={"req_type": "json"})  # 工作地点 ID
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 工作地点名称


@attr.s
class GetEHREmployeeListRespItemSystemFieldsJobLevel(object):
    id: int = attr.ib(default=0, metadata={"req_type": "json"})  # 职级 ID
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 职级名称


@attr.s
class GetEHREmployeeListRespItemSystemFieldsJob(object):
    id: int = attr.ib(default=0, metadata={"req_type": "json"})  # 职位 ID
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 职位名称


@attr.s
class GetEHREmployeeListRespItemSystemFieldsManager(object):
    user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 上级的用户 ID（user_id）
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文名
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名


@attr.s
class GetEHREmployeeListRespItemSystemFields(object):
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文姓名
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文姓名
    email: str = attr.ib(default="", metadata={"req_type": "json"})  # 邮箱
    mobile: str = attr.ib(default="", metadata={"req_type": "json"})  # 手机号码
    department_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 部门的飞书 open_department_id
    manager: GetEHREmployeeListRespItemSystemFieldsManager = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 上级
    job: GetEHREmployeeListRespItemSystemFieldsJob = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 职位
    job_level: GetEHREmployeeListRespItemSystemFieldsJobLevel = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 职级
    work_location: GetEHREmployeeListRespItemSystemFieldsWorkLocation = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 工作地点
    gender: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 性别, 可选值有: `1`：男, `2`：女
    birthday: str = attr.ib(default="", metadata={"req_type": "json"})  # 出生日期
    native_region: GetEHREmployeeListRespItemSystemFieldsNativeRegion = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 籍贯
    ethnicity: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 民族, 可选值有: `1`：汉族, `2`：蒙古族, `3`：回族, `4`：藏族, `5`：维吾尔族, `6`：苗族, `7`：彝族, `8`：壮族, `9`：布依族, `10`：朝鲜族, `11`：满族, `12`：侗族, `13`：瑶族, `14`：白族, `15`：土家族, `16`：哈尼族, `17`：哈萨克族, `18`：傣族, `19`：黎族, `20`：傈僳族, `21`：佤族, `22`：畲族, `23`：高山族, `24`：拉祜族, `25`：水族, `26`：东乡族, `27`：纳西族, `28`：景颇族, `29`：阿昌族, `30`：柯尔克孜族, `31`：土族, `32`：达斡尔族, `33`：仫佬族, `34`：羌族, `35`：布朗族, `36`：撒拉族, `37`：毛南族, `38`：仡佬族, `39`：锡伯族, `40`：普米族, `41`：塔吉克族, `42`：怒族, `43`：乌孜别克族, `44`：俄罗斯族, `45`：鄂温克族, `46`：德昂族, `47`：保安族, `48`：裕固族, `49`：京族, `50`：塔塔尔族, `51`：独龙族, `52`：鄂伦春族, `53`：赫哲族, `54`：门巴族, `55`：珞巴族, `56`：基诺族, `57`：其他
    marital_status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 婚姻状况, 可选值有: `1`：未婚, `2`：已婚, `3`：离异, `4`：其他
    political_status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 政治面貌, 可选值有: `1`：中共党员, `2`：中国农工民主党, `3`：中国国民党革命委员会, `4`：中国民主促进会会员, `5`：中国民主同盟成员, `6`：中国民主建国会, `7`：中国致公党党员, `8`：九三学社社员, `9`：共青团员, `10`：其它党派成员, `11`：民主人士, `12`：群众
    entered_workforce_date: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 参加工作日期
    id_type: GetEHREmployeeListRespItemSystemFieldsIDType = attr.ib(
        factory=lambda: GetEHREmployeeListRespItemSystemFieldsIDType(),
        metadata={"req_type": "json"},
    )  # 证件类型, 可选值有: `1`：居民身份证, `2`：港澳居民来往内地通行证, `3`：台湾居民来往大陆通行证, `4`：护照, `5`：其他
    id_number: str = attr.ib(default="", metadata={"req_type": "json"})  # 证件号
    hukou_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 户口类型, 可选值有: `1`：本市城镇, `2`：外埠城镇, `3`：本市农村, `4`：外埠农村
    hukou_location: str = attr.ib(default="", metadata={"req_type": "json"})  # 户口所在地
    bank_account_number: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 银行卡号
    bank_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 开户行
    social_security_account: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 社保账号
    provident_fund_account: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 公积金账号
    employee_no: str = attr.ib(default="", metadata={"req_type": "json"})  # 工号
    employee_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 雇员类型, 可选值有: `1`：全职, `2`：实习, `3`：顾问, `4`：外包, `5`：劳务
    status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 员工状态, 可选值有: `1`：待入职, `2`：在职, `3`：已取消入职, `4`：待离职, `5`：已离职
    hire_date: str = attr.ib(default="", metadata={"req_type": "json"})  # 入职日期
    probation_months: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 试用期（月）
    conversion_date: str = attr.ib(default="", metadata={"req_type": "json"})  # 转正日期
    application: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 转正申请, 可选值有: `1`：未申请, `2`：审批中, `3`：被驳回, `4`：已通过
    application_status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 转正状态, 可选值有: `1`：无需转正, `2`：待转正, `3`：已转正
    last_day: str = attr.ib(default="", metadata={"req_type": "json"})  # 离职日期
    departure_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 离职类型, 可选值有: `1`：主动, `2`：被动
    departure_reason: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 离职原因, 可选值有: `1`：身体、家庭原因, `2`：职业发展, `3`：薪资福利不满意, `4`：工作压力大, `5`：合同到期不续签, `6`：其他, `7`：无法胜任工作, `8`：组织业务调整和岗位优化, `9`：违反公司条例, `10`：试用期未通过, `11`：其他
    departure_notes: str = attr.ib(default="", metadata={"req_type": "json"})  # 离职备注
    contract_company: GetEHREmployeeListRespItemSystemFieldsContractCompany = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 合同公司
    contract_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 合同类型, 可选值有: `1`：固定期限劳动合同, `2`：无固定期限劳动合同, `3`：实习协议, `4`：外包协议, `5`：劳务派遣合同, `6`：返聘协议, `7`：其他
    contract_start_date: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 合同开始日期
    contract_expiration_date: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 合同到期日期
    contract_sign_times: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 劳动合同签订次数
    personal_email: str = attr.ib(default="", metadata={"req_type": "json"})  # 个人邮箱
    family_address: str = attr.ib(default="", metadata={"req_type": "json"})  # 家庭地址
    primary_emergency_contact: GetEHREmployeeListRespItemSystemFieldsPrimaryEmergencyContact = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 主要紧急联系人
    emergency_contact: typing.List[
        GetEHREmployeeListRespItemSystemFieldsEmergencyContact
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 紧急联系人
    highest_level_of_edu: GetEHREmployeeListRespItemSystemFieldsHighestLevelOfEdu = (
        attr.ib(default=None, metadata={"req_type": "json"})
    )  # 最高学历
    education: typing.List[GetEHREmployeeListRespItemSystemFieldsEducation] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 教育经历
    former_work_exp: GetEHREmployeeListRespItemSystemFieldsFormerWorkExp = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 前工作经历
    work_exp: typing.List[GetEHREmployeeListRespItemSystemFieldsWorkExp] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 工作经历
    id_photo_po_side: typing.List[
        GetEHREmployeeListRespItemSystemFieldsIDPhotoPoSide
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 身份证照片（人像面）
    id_photo_em_side: typing.List[
        GetEHREmployeeListRespItemSystemFieldsIDPhotoEmSide
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 身份证照片（国徽面）
    id_photo: typing.List[GetEHREmployeeListRespItemSystemFieldsIDPhoto] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 证件照
    diploma_photo: typing.List[
        GetEHREmployeeListRespItemSystemFieldsDiplomaPhoto
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 学位证书
    graduation_cert: typing.List[
        GetEHREmployeeListRespItemSystemFieldsGraduationCert
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 毕业证书
    cert_of_merit: typing.List[
        GetEHREmployeeListRespItemSystemFieldsCertOfMerit
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 奖励证明
    offboarding_file: typing.List[
        GetEHREmployeeListRespItemSystemFieldsOffboardingFile
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 离职证明
    cancel_onboarding_reason: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 取消入职原因, 可选值有: `1`：个人原因, `2`：原单位留任, `3`：接受其他 Offer, `4`：其他
    cancel_onboarding_notes: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 取消入职备注
    employee_form_status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 入职登记表状态, 可选值有: `1`：未发送, `2`：待提交, `3`：已提交
    create_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 创建时间
    update_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 更新时间


@attr.s
class GetEHREmployeeListRespItem(object):
    user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 员工的用户 ID,user_id_type 为 user_id 时返回 user_id；,user_id_type 为 open_id 时返回 open_id；,user_id_type 为 union_id 时返回 uion_id；,「待入职」和「已取消入职」的员工，此字段值为 null
    system_fields: GetEHREmployeeListRespItemSystemFields = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 系统字段
    custom_fields: typing.List[GetEHREmployeeListRespItemCustomField] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 自定义字段


@attr.s
class GetEHREmployeeListResp(object):
    items: typing.List[GetEHREmployeeListRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 员工列表
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否还有更多项


def _gen_get_ehr_employee_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetEHREmployeeListResp,
        scope="EHR",
        api="GetEHREmployeeList",
        method="GET",
        url="https://open.feishu.cn/open-apis/ehr/v1/employees",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateHelpdeskTicketReqCustomizedField(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 自定义字段ID, 示例值："123"
    value: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 自定义字段值, 示例值："value"
    key_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 键名, 示例值："key"


@attr.s
class UpdateHelpdeskTicketReq(object):
    ticket_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 工单ID, 示例值："6945345902185807891"
    status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # new status, 1: 已创建, 2: 处理中, 3: 排队中, 5: 待定, 50: 机器人关闭工单, 51: 关闭工单, 示例值：1
    tag_names: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 新标签名
    comment: str = attr.ib(default="", metadata={"req_type": "json"})  # 新评论, 示例值："good"
    customized_fields: typing.List[UpdateHelpdeskTicketReqCustomizedField] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 自定义字段
    ticket_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # ticket stage, 示例值：1
    solved: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 工单是否解决，1: 未解决, 2: 已解决, 示例值：1
    channel: int = attr.ib(default=0, metadata={"req_type": "json"})  # 工单来源渠道ID, 示例值：1


@attr.s
class UpdateHelpdeskTicketResp(object):
    pass


def _gen_update_helpdesk_ticket_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateHelpdeskTicketResp,
        scope="Helpdesk",
        api="UpdateHelpdeskTicket",
        method="PUT",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/tickets/:ticket_id",
        body=request,
        method_option=_new_method_option(options),
        need_user_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class SearchDriveFileReq(object):
    search_key: str = attr.ib(default="", metadata={"req_type": "json"})  # 搜索关键字
    count: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 搜索返回数量，0 <= count <= 50
    offset: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 搜索偏移位，offset >= 0，offset + count < 200
    owner_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 文档所有者的userid
    chat_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 文档所在群的chatid
    docs_types: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 文档类型，支持："doc", "sheet", "slide", "bitable", "mindnote", "file"


@attr.s
class SearchDriveFileRespDocsEntity(object):
    docs_token: str = attr.ib(default="", metadata={"req_type": "json"})  # 文档token
    docs_type: str = attr.ib(default="", metadata={"req_type": "json"})  # 文档类型
    title: str = attr.ib(default="", metadata={"req_type": "json"})  # 标题
    owner_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件所有者


@attr.s
class SearchDriveFileResp(object):
    docs_entities: typing.List[SearchDriveFileRespDocsEntity] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 搜索匹配文档列表
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 搜索偏移位结果列表后是否还有数据
    total: int = attr.ib(default=0, metadata={"req_type": "json"})  # 搜索匹配文档总数量


def _gen_search_drive_file_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=SearchDriveFileResp,
        scope="Drive",
        api="SearchDriveFile",
        method="POST",
        url="https://open.feishu.cn/open-apis/suite/docs-api/search/object",
        body=request,
        method_option=_new_method_option(options),
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteDriveCommentReqFileType(object):
    pass


@attr.s
class DeleteDriveCommentReq(object):
    file_type: DeleteDriveCommentReqFileType = attr.ib(
        factory=lambda: DeleteDriveCommentReqFileType(), metadata={"req_type": "query"}
    )  # 文档类型, 示例值："doc", 可选值有: `doc`：文档, `sheet`：表格, `file`：文件
    file_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 文档token, 示例值："doccnHh7U87HOFpii5u5G*****"
    comment_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 评论ID, 示例值："6916106822734578184"
    reply_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 回复ID, 示例值："6916106822734594568"


@attr.s
class DeleteDriveCommentResp(object):
    pass


def _gen_delete_drive_comment_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteDriveCommentResp,
        scope="Drive",
        api="DeleteDriveComment",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/drive/v1/files/:file_token/comments/:comment_id/replies/:reply_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class FinishUploadDriveFileReq(object):
    upload_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分片上传事务ID, 示例值："123456"
    block_num: int = attr.ib(default=0, metadata={"req_type": "json"})  # 分片数量, 示例值：1


@attr.s
class FinishUploadDriveFileResp(object):
    file_token: str = attr.ib(default="", metadata={"req_type": "json"})  # 新创建的文件token


def _gen_finish_upload_drive_file_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=FinishUploadDriveFileResp,
        scope="Drive",
        api="FinishUploadDriveFile",
        method="POST",
        url="https://open.feishu.cn/open-apis/drive/v1/files/upload_finish",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetChatReqUserIDType(object):
    pass


@attr.s
class GetChatReq(object):
    user_id_type: GetChatReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    chat_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 群 ID, 示例值："oc_a0553eda9014c201e6969b478895c230"


@attr.s
class GetChatRespModerationPermission(object):
    pass


@attr.s
class GetChatRespMembershipApproval(object):
    pass


@attr.s
class GetChatRespLeaveMessageVisibility(object):
    pass


@attr.s
class GetChatRespJoinMessageVisibility(object):
    pass


@attr.s
class GetChatRespChatType(object):
    pass


@attr.s
class GetChatRespOwnerIDType(object):
    pass


@attr.s
class GetChatRespEditPermission(object):
    pass


@attr.s
class GetChatRespAtAllPermission(object):
    pass


@attr.s
class GetChatRespShareCardPermission(object):
    pass


@attr.s
class GetChatRespAddMemberPermission(object):
    pass


@attr.s
class GetChatRespI18nNames(object):
    zh_cn: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文名
    en_us: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名
    ja_jp: str = attr.ib(default="", metadata={"req_type": "json"})  # 日文名


@attr.s
class GetChatResp(object):
    avatar: str = attr.ib(default="", metadata={"req_type": "json"})  # 群头像 URL
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 群名称
    description: str = attr.ib(default="", metadata={"req_type": "json"})  # 群描述
    i18n_names: GetChatRespI18nNames = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 群国际化名称
    add_member_permission: GetChatRespAddMemberPermission = attr.ib(
        factory=lambda: GetChatRespAddMemberPermission(), metadata={"req_type": "json"}
    )  # 群成员添加权限(all_members/only_owner)
    share_card_permission: GetChatRespShareCardPermission = attr.ib(
        factory=lambda: GetChatRespShareCardPermission(), metadata={"req_type": "json"}
    )  # 群分享权限(allowed/not_allowed)
    at_all_permission: GetChatRespAtAllPermission = attr.ib(
        factory=lambda: GetChatRespAtAllPermission(), metadata={"req_type": "json"}
    )  # at 所有人权限(all_members/only_owner)
    edit_permission: GetChatRespEditPermission = attr.ib(
        factory=lambda: GetChatRespEditPermission(), metadata={"req_type": "json"}
    )  # 群编辑权限(all_members/only_owner)
    owner_id_type: GetChatRespOwnerIDType = attr.ib(
        factory=lambda: GetChatRespOwnerIDType(), metadata={"req_type": "json"}
    )  # 群主 ID 的类型(open_id/user_id/union_id)，群主是机器人时，不返回该字段。
    owner_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 群主 ID，群主是机器人时，不返回该字段。
    chat_mode: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 群模式(group/topic/p2p)
    chat_type: GetChatRespChatType = attr.ib(
        factory=lambda: GetChatRespChatType(), metadata={"req_type": "json"}
    )  # 群类型(private/public)
    chat_tag: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 优先级最高的一个群tag(inner/tenant/department/edu/meeting/customer_service)
    join_message_visibility: GetChatRespJoinMessageVisibility = attr.ib(
        factory=lambda: GetChatRespJoinMessageVisibility(),
        metadata={"req_type": "json"},
    )  # 入群消息可见性(only_owner/all_members/not_anyone)
    leave_message_visibility: GetChatRespLeaveMessageVisibility = attr.ib(
        factory=lambda: GetChatRespLeaveMessageVisibility(),
        metadata={"req_type": "json"},
    )  # 出群消息可见性(only_owner/all_members/not_anyone)
    membership_approval: GetChatRespMembershipApproval = attr.ib(
        factory=lambda: GetChatRespMembershipApproval(), metadata={"req_type": "json"}
    )  # 加群审批(no_approval_required/approval_required)
    moderation_permission: GetChatRespModerationPermission = attr.ib(
        factory=lambda: GetChatRespModerationPermission(), metadata={"req_type": "json"}
    )  # 发言权限(all_members/only_owner/moderator_list)


def _gen_get_chat_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetChatResp,
        scope="Chat",
        api="GetChat",
        method="GET",
        url="https://open.feishu.cn/open-apis/im/v1/chats/:chat_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateBitableTableReqTable(object):
    name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 数据表 名字, 示例值："table1"


@attr.s
class CreateBitableTableReqUserIDType(object):
    pass


@attr.s
class CreateBitableTableReq(object):
    user_id_type: CreateBitableTableReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    app_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # bitable app token, 示例值："appbcbWCzen6D8dezhoCH2RpMAh"
    table: CreateBitableTableReqTable = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 数据表


@attr.s
class CreateBitableTableResp(object):
    table_id: str = attr.ib(default="", metadata={"req_type": "json"})  # table id


def _gen_create_bitable_table_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateBitableTableResp,
        scope="Bitable",
        api="CreateBitableTable",
        method="POST",
        url="https://open.feishu.cn/open-apis/bitable/v1/apps/:app_token/tables",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_meeting_room_summary_batch_get import (
    BatchGetMeetingRoomSummaryReq,
    BatchGetMeetingRoomSummaryResp,
    _gen_batch_get_meeting_room_summary_req,
)
from pylark.api_service_meeting_room_building_get_list import (
    GetMeetingRoomBuildingListReq,
    GetMeetingRoomBuildingListResp,
    _gen_get_meeting_room_building_list_req,
)
from pylark.api_service_meeting_room_building_batch_get import (
    BatchGetMeetingRoomBuildingReq,
    BatchGetMeetingRoomBuildingResp,
    _gen_batch_get_meeting_room_building_req,
)
from pylark.api_service_meeting_room_room_get_list import (
    GetMeetingRoomRoomListReq,
    GetMeetingRoomRoomListResp,
    _gen_get_meeting_room_room_list_req,
)
from pylark.api_service_meeting_room_room_batch_get import (
    BatchGetMeetingRoomRoomReq,
    BatchGetMeetingRoomRoomResp,
    _gen_batch_get_meeting_room_room_req,
)
from pylark.api_service_meeting_room_freebusy_batch_get import (
    BatchGetMeetingRoomFreebusyReq,
    BatchGetMeetingRoomFreebusyResp,
    _gen_batch_get_meeting_room_freebusy_req,
)
from pylark.api_service_meeting_room_instance_reply import (
    ReplyMeetingRoomInstanceReq,
    ReplyMeetingRoomInstanceResp,
    _gen_reply_meeting_room_instance_req,
)
from pylark.api_service_meeting_room_building_create import (
    CreateMeetingRoomBuildingReq,
    CreateMeetingRoomBuildingResp,
    _gen_create_meeting_room_building_req,
)
from pylark.api_service_meeting_room_building_update import (
    UpdateMeetingRoomBuildingReq,
    UpdateMeetingRoomBuildingResp,
    _gen_update_meeting_room_building_req,
)
from pylark.api_service_meeting_room_building_delete import (
    DeleteMeetingRoomBuildingReq,
    DeleteMeetingRoomBuildingResp,
    _gen_delete_meeting_room_building_req,
)
from pylark.api_service_meeting_room_building_batch_get_id import (
    BatchGetMeetingRoomBuildingIDReq,
    BatchGetMeetingRoomBuildingIDResp,
    _gen_batch_get_meeting_room_building_id_req,
)
from pylark.api_service_meeting_room_room_create import (
    CreateMeetingRoomRoomReq,
    CreateMeetingRoomRoomResp,
    _gen_create_meeting_room_room_req,
)
from pylark.api_service_meeting_room_room_update import (
    UpdateMeetingRoomRoomReq,
    UpdateMeetingRoomRoomResp,
    _gen_update_meeting_room_room_req,
)
from pylark.api_service_meeting_room_room_delete import (
    DeleteMeetingRoomRoomReq,
    DeleteMeetingRoomRoomResp,
    _gen_delete_meeting_room_room_req,
)
from pylark.api_service_meeting_room_room_batch_get_id import (
    BatchGetMeetingRoomRoomIDReq,
    BatchGetMeetingRoomRoomIDResp,
    _gen_batch_get_meeting_room_room_id_req,
)
from pylark.api_service_meeting_room_country_get_list import (
    GetMeetingRoomCountryListReq,
    GetMeetingRoomCountryListResp,
    _gen_get_meeting_room_country_list_req,
)
from pylark.api_service_meeting_room_district_get_list import (
    GetMeetingRoomDistrictListReq,
    GetMeetingRoomDistrictListResp,
    _gen_get_meeting_room_district_list_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkMeetingRoomService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def batch_get_meeting_room_summary(
        self, request: BatchGetMeetingRoomSummaryReq, options: typing.List[str] = None
    ) -> typing.Tuple[BatchGetMeetingRoomSummaryResp, Response]:
        return self.cli.raw_request(
            _gen_batch_get_meeting_room_summary_req(request, options)
        )

    def get_meeting_room_building_list(
        self, request: GetMeetingRoomBuildingListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetMeetingRoomBuildingListResp, Response]:
        return self.cli.raw_request(
            _gen_get_meeting_room_building_list_req(request, options)
        )

    def batch_get_meeting_room_building(
        self, request: BatchGetMeetingRoomBuildingReq, options: typing.List[str] = None
    ) -> typing.Tuple[BatchGetMeetingRoomBuildingResp, Response]:
        return self.cli.raw_request(
            _gen_batch_get_meeting_room_building_req(request, options)
        )

    def get_meeting_room_room_list(
        self, request: GetMeetingRoomRoomListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetMeetingRoomRoomListResp, Response]:
        return self.cli.raw_request(
            _gen_get_meeting_room_room_list_req(request, options)
        )

    def batch_get_meeting_room_room(
        self, request: BatchGetMeetingRoomRoomReq, options: typing.List[str] = None
    ) -> typing.Tuple[BatchGetMeetingRoomRoomResp, Response]:
        return self.cli.raw_request(
            _gen_batch_get_meeting_room_room_req(request, options)
        )

    def batch_get_meeting_room_freebusy(
        self, request: BatchGetMeetingRoomFreebusyReq, options: typing.List[str] = None
    ) -> typing.Tuple[BatchGetMeetingRoomFreebusyResp, Response]:
        return self.cli.raw_request(
            _gen_batch_get_meeting_room_freebusy_req(request, options)
        )

    def reply_meeting_room_instance(
        self, request: ReplyMeetingRoomInstanceReq, options: typing.List[str] = None
    ) -> typing.Tuple[ReplyMeetingRoomInstanceResp, Response]:
        return self.cli.raw_request(
            _gen_reply_meeting_room_instance_req(request, options)
        )

    def create_meeting_room_building(
        self, request: CreateMeetingRoomBuildingReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateMeetingRoomBuildingResp, Response]:
        return self.cli.raw_request(
            _gen_create_meeting_room_building_req(request, options)
        )

    def update_meeting_room_building(
        self, request: UpdateMeetingRoomBuildingReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateMeetingRoomBuildingResp, Response]:
        return self.cli.raw_request(
            _gen_update_meeting_room_building_req(request, options)
        )

    def delete_meeting_room_building(
        self, request: DeleteMeetingRoomBuildingReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteMeetingRoomBuildingResp, Response]:
        return self.cli.raw_request(
            _gen_delete_meeting_room_building_req(request, options)
        )

    def batch_get_meeting_room_building_id(
        self,
        request: BatchGetMeetingRoomBuildingIDReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[BatchGetMeetingRoomBuildingIDResp, Response]:
        return self.cli.raw_request(
            _gen_batch_get_meeting_room_building_id_req(request, options)
        )

    def create_meeting_room_room(
        self, request: CreateMeetingRoomRoomReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateMeetingRoomRoomResp, Response]:
        return self.cli.raw_request(_gen_create_meeting_room_room_req(request, options))

    def update_meeting_room_room(
        self, request: UpdateMeetingRoomRoomReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateMeetingRoomRoomResp, Response]:
        return self.cli.raw_request(_gen_update_meeting_room_room_req(request, options))

    def delete_meeting_room_room(
        self, request: DeleteMeetingRoomRoomReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteMeetingRoomRoomResp, Response]:
        return self.cli.raw_request(_gen_delete_meeting_room_room_req(request, options))

    def batch_get_meeting_room_room_id(
        self, request: BatchGetMeetingRoomRoomIDReq, options: typing.List[str] = None
    ) -> typing.Tuple[BatchGetMeetingRoomRoomIDResp, Response]:
        return self.cli.raw_request(
            _gen_batch_get_meeting_room_room_id_req(request, options)
        )

    def get_meeting_room_country_list(
        self, request: GetMeetingRoomCountryListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetMeetingRoomCountryListResp, Response]:
        return self.cli.raw_request(
            _gen_get_meeting_room_country_list_req(request, options)
        )

    def get_meeting_room_district_list(
        self, request: GetMeetingRoomDistrictListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetMeetingRoomDistrictListResp, Response]:
        return self.cli.raw_request(
            _gen_get_meeting_room_district_list_req(request, options)
        )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CropFaceVerifyImageReqRawImage(object):
    pass


@attr.s
class CropFaceVerifyImageReq(object):
    raw_image: typing.Union[str, bytes, io.BytesIO] = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 带有头像的人脸照片文件名称


@attr.s
class CropFaceVerifyImageResp(object):
    face_image: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # BASE64(裁剪后的人脸基准图片)，code为0时返回


def _gen_crop_face_verify_image_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CropFaceVerifyImageResp,
        scope="HumanAuth",
        api="CropFaceVerifyImage",
        method="POST",
        url="https://open.feishu.cn/open-apis/face_verify/v1/crop_face_image",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        is_file=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class AddBotToChatReq(object):
    chat_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 群的id


@attr.s
class AddBotToChatResp(object):
    pass


def _gen_add_bot_to_chat_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=AddBotToChatResp,
        scope="Bot",
        api="AddBotToChat",
        method="POST",
        url="https://open.feishu.cn/open-apis/bot/v4/add",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateCalendarACLReqScope(object):
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 权限类型，当type为User时，值为open_id/user_id/union_id, 示例值："user", 可选值有: `user`：用户
    user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户ID, 示例值："ou_xxxxxx"


@attr.s
class CreateCalendarACLReqRole(object):
    pass


@attr.s
class CreateCalendarACLReqUserIDType(object):
    pass


@attr.s
class CreateCalendarACLReq(object):
    user_id_type: CreateCalendarACLReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    calendar_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 日历ID, 示例值："feishu.cn_xxxxxxxxxx@group.calendar.feishu.cn"
    role: CreateCalendarACLReqRole = attr.ib(
        factory=lambda: CreateCalendarACLReqRole(), metadata={"req_type": "json"}
    )  # 对日历的访问权限, 示例值："writer", 可选值有: `unknown`：未知权限, `free_busy_reader`：游客，只能看到忙碌/空闲信息, `reader`：订阅者，查看所有日程详情, `writer`：编辑者，创建及修改日程, `owner`：管理员，管理日历及共享设置
    scope: CreateCalendarACLReqScope = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 权限范围


@attr.s
class CreateCalendarACLRespScope(object):
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 权限类型，当type为User时，值为open_id/user_id/union_id, 可选值有: `user`：用户
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID


@attr.s
class CreateCalendarACLRespRole(object):
    pass


@attr.s
class CreateCalendarACLResp(object):
    acl_id: str = attr.ib(default="", metadata={"req_type": "json"})  # acl资源ID
    role: CreateCalendarACLRespRole = attr.ib(
        factory=lambda: CreateCalendarACLRespRole(), metadata={"req_type": "json"}
    )  # 对日历的访问权限, 可选值有: `unknown`：未知权限, `free_busy_reader`：游客，只能看到忙碌/空闲信息, `reader`：订阅者，查看所有日程详情, `writer`：编辑者，创建及修改日程, `owner`：管理员，管理日历及共享设置
    scope: CreateCalendarACLRespScope = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 权限范围


def _gen_create_calendar_acl_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateCalendarACLResp,
        scope="Calendar",
        api="CreateCalendarACL",
        method="POST",
        url="https://open.feishu.cn/open-apis/calendar/v4/calendars/:calendar_id/acls",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteAttendanceGroupReq(object):
    group_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 考勤组的 ID，需要从获取打卡结果的接口中获取 group_id，示例值："6919358128597097404"


@attr.s
class DeleteAttendanceGroupResp(object):
    pass


def _gen_delete_attendance_group_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteAttendanceGroupResp,
        scope="Attendance",
        api="DeleteAttendanceGroup",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/attendance/v1/groups/:group_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHireApplicationInterviewListReqUserIDType(object):
    pass


@attr.s
class GetHireApplicationInterviewListReq(object):
    page_size: int = attr.ib(default=0, metadata={"req_type": "query"})  # 分页大小, 示例值：10
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果, 示例值："xx"
    user_id_type: GetHireApplicationInterviewListReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    application_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 投递ID, 示例值："6949805467799537964"


@attr.s
class GetHireApplicationInterviewListRespItemInterviewRecordInterviewScore(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 面试评分id
    level: int = attr.ib(default=0, metadata={"req_type": "json"})  # 分数级别
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文名称
    zh_description: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文描述
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名称
    en_description: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文描述


@attr.s
class GetHireApplicationInterviewListRespItemInterviewRecord(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 面试记录id
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 面试官用户id
    content: str = attr.ib(default="", metadata={"req_type": "json"})  # 面试评价
    min_job_level_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 建议定级下限的职级id
    max_job_level_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 建议定级上限的职级id
    commit_status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 提交状态, 可选值有: `1`：已提交, `2`：未提交
    conclusion: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 面试结论, 可选值有: `1`：通过, `2`：未通过, `3`：未开始, `4`：未提交, `5`：未到场
    interview_score: GetHireApplicationInterviewListRespItemInterviewRecordInterviewScore = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 面试评分


@attr.s
class GetHireApplicationInterviewListRespItem(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 面试id
    begin_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 面试开始时间（ms）
    end_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 面试结束时间（ms）
    round: int = attr.ib(default=0, metadata={"req_type": "json"})  # 面试轮次（从0开始计数）
    stage_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 面试关联的投递阶段
    interview_record_list: typing.List[
        GetHireApplicationInterviewListRespItemInterviewRecord
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 面试官记录列表


@attr.s
class GetHireApplicationInterviewListResp(object):
    page_token: str = attr.ib(default="", metadata={"req_type": "json"})  # 分页标志
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否有更多
    items: typing.List[GetHireApplicationInterviewListRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 面试列表


def _gen_get_hire_application_interview_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHireApplicationInterviewListResp,
        scope="Hire",
        api="GetHireApplicationInterviewList",
        method="GET",
        url="https://open.feishu.cn/open-apis/hire/v1/applications/:application_id/interviews",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class SetVCPermissionMeetingRecordingReqPermissionObject(object):
    id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 授权对象ID, 示例值："ou_3ec3f6a28a0d08c45d895276e8e5e19b"
    type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 授权对象类型, 示例值：1, 可选值有: `1`：用户授权, `2`：群组授权, `3`：租户内授权（id字段不填）, `4`：公网授权（id字段不填）
    permission: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 权限, 示例值：1, 可选值有: `1`：查看


@attr.s
class SetVCPermissionMeetingRecordingReqUserIDType(object):
    pass


@attr.s
class SetVCPermissionMeetingRecordingReq(object):
    user_id_type: SetVCPermissionMeetingRecordingReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`,, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    meeting_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 会议ID（视频会议的唯一标识，视频会议开始后才会产生）, 示例值："6911188411932033028"
    permission_objects: typing.List[
        SetVCPermissionMeetingRecordingReqPermissionObject
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 授权对象列表


@attr.s
class SetVCPermissionMeetingRecordingResp(object):
    pass


def _gen_set_vc_permission_meeting_recording_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=SetVCPermissionMeetingRecordingResp,
        scope="VC",
        api="SetVCPermissionMeetingRecording",
        method="PATCH",
        url="https://open.feishu.cn/open-apis/vc/v1/meetings/:meeting_id/recording/set_permission",
        body=request,
        method_option=_new_method_option(options),
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetVCRoomConfigReq(object):
    scope: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 查询节点范围, 示例值：5, 可选值有: `1`：租户, `2`：国家/地区, `3`：城市, `4`：建筑, `5`：楼层, `6`：会议室
    country_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 国家/地区ID scope为2，3时需要此参数, 示例值："086"
    district_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 城市ID scope为3时需要此参数, 示例值："001"
    building_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 建筑ID scope为4，5时需要此参数, 示例值："22"
    floor_name: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 楼层 scope为5时需要此参数, 示例值："4"
    room_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 会议室ID scope为6时需要此参数, 示例值："6383786266263"


@attr.s
class GetVCRoomConfigRespDigitalSignageMaterial(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 素材ID
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 素材名称
    material_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 素材类型, 可选值有: `1`：图片, `2`：视频, `3`：GIF
    url: str = attr.ib(default="", metadata={"req_type": "json"})  # 素材url
    duration: int = attr.ib(default=0, metadata={"req_type": "json"})  # 播放时长（单位sec）
    cover: str = attr.ib(default="", metadata={"req_type": "json"})  # 素材封面url
    md5: str = attr.ib(default="", metadata={"req_type": "json"})  # 素材文件md5


@attr.s
class GetVCRoomConfigRespDigitalSignage(object):
    enable: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否开启数字标牌功能
    mute: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否静音播放
    start_display: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 日程会议开始前n分钟结束播放
    stop_display: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 会议结束后n分钟开始播放
    materials: typing.List[GetVCRoomConfigRespDigitalSignageMaterial] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 素材列表


@attr.s
class GetVCRoomConfigResp(object):
    room_background: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 飞书会议室背景图
    display_background: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 飞书签到板背景图
    digital_signage: GetVCRoomConfigRespDigitalSignage = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 飞书会议室数字标牌


def _gen_get_vc_room_config_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetVCRoomConfigResp,
        scope="VC",
        api="GetVCRoomConfig",
        method="GET",
        url="https://open.feishu.cn/open-apis/vc/v1/room_configs/query",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateDriveFileReq(object):
    folder_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 文件夹 token，用于在此文件夹下新建文档，获取方式见[概述](https://open.feishu.cn/document/ukTMukTMukTM/uUDN04SN0QjL1QDN/files/guide/introduction)
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 需要创建文档的类型  "doc" 、 "sheet"  or  "bitable"
    title: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 创建文档的标题。注：type 为 "doc" 时不可用（非必填，请求会被过滤），有创建带标题doc文档需求可用 [创建文档](https://open.feishu.cn/document/ukTMukTMukTM/ugDM2YjL4AjN24COwYjN) 接口


@attr.s
class CreateDriveFileResp(object):
    url: str = attr.ib(default="", metadata={"req_type": "json"})  # 新创建文档的 url
    revision: int = attr.ib(default=0, metadata={"req_type": "json"})  # 新创建文档的版本号


def _gen_create_drive_file_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateDriveFileResp,
        scope="Drive",
        api="CreateDriveFile",
        method="POST",
        url="https://open.feishu.cn/open-apis/drive/explorer/v2/file/:folderToken",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHireAttachmentPreviewReq(object):
    attachment_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 附件id, 示例值："11111"


@attr.s
class GetHireAttachmentPreviewResp(object):
    url: str = attr.ib(default="", metadata={"req_type": "json"})  # 预览链接


def _gen_get_hire_attachment_preview_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHireAttachmentPreviewResp,
        scope="Hire",
        api="GetHireAttachmentPreview",
        method="GET",
        url="https://open.feishu.cn/open-apis/hire/v1/attachments/:attachment_id/preview",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DownloadEHRAttachmentsReq(object):
    token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 文件 token, 示例值："09bf7b924f9a4a69875788891b5970d8"


@attr.s
class DownloadEHRAttachmentsRespFile(object):
    pass


@attr.s
class DownloadEHRAttachmentsResp(object):
    file: typing.Union[str, bytes, io.BytesIO] = attr.ib(
        default=None, metadata={"req_type": "json"}
    )


@attr.s
class DownloadEHRAttachmentsResp(object):
    is_file: bool = attr.ib(factory=lambda: bool(), metadata={"req_type": "json"})
    code: int = attr.ib(default=0, metadata={"req_type": "json"})
    msg: str = attr.ib(default="", metadata={"req_type": "json"})
    data: DownloadEHRAttachmentsResp = attr.ib(
        default=None, metadata={"req_type": "json"}
    )


def _gen_download_ehr_attachments_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DownloadEHRAttachmentsResp,
        scope="EHR",
        api="DownloadEHRAttachments",
        method="GET",
        url="https://open.feishu.cn/open-apis/ehr/v1/attachments/:token",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )
